# coding: utf-8

"""
    Mentortools Deep Agent API

    FastAPI service for running Mentortools deep agent

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, Field, StrictStr
from deep_agent_sdk.models.portal_owner_info import PortalOwnerInfo

class PortalInfo(BaseModel):
    """
    Portal context for the run — language, domain, branding, owner info.  # noqa: E501
    """
    language: Optional[StrictStr] = Field(default='en', description="ISO language code (e.g. 'en', 'de'). Agent responds in this language.")
    domain: Optional[StrictStr] = Field(default='', description="Portal domain (e.g. 'myportal.mentortools.com')")
    owner: Optional[PortalOwnerInfo] = Field(default=None, description="Portal owner details")
    __properties = ["language", "domain", "owner"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> PortalInfo:
        """Create an instance of PortalInfo from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of owner
        if self.owner:
            _dict['owner'] = self.owner.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> PortalInfo:
        """Create an instance of PortalInfo from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return PortalInfo.parse_obj(obj)

        _obj = PortalInfo.parse_obj({
            "language": obj.get("language") if obj.get("language") is not None else 'en',
            "domain": obj.get("domain") if obj.get("domain") is not None else '',
            "owner": PortalOwnerInfo.from_dict(obj.get("owner")) if obj.get("owner") is not None else None
        })
        return _obj


